Documentation
¶
Overview ¶
Package vcs abstracts VCS interactions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type VCS ¶
type VCS interface {
// Name is a short string naming the vcs. Ie: git, hg, svn
Name() string
// Remote will return the url for the given remote. If no remote is given
// the default for the version control system will be used.
Remote(name string) string
// Root will return the root of the repository.
Root() string
// Commit returns the current commit id of repository.
Commit() string
// ShortCommit returns a shortened form of Commit().
ShortCommit() string
// Branch returns the currently checked out branch of the repository.
Branch() string
// Config will look up a setting in the configuration for the repository
// and return a slice of values for the given key.
Config(key string) []string
}
VCS is an interface into the individual version control tools.
Click to show internal directories.
Click to hide internal directories.